@@ -16,6 +16,15 @@ extern "C" {
 #define sys (( PDrawableData) var-> sysData)
 #define ctx (( Context*) context)
 
+typedef struct {
+	HDC dc;
+	HGLRC gl;
+} ContextStackEntry;
+
+ContextStackEntry stack[CONTEXT_STACK_SIZE];
+int               stack_ptr = 0;
+
+
 typedef struct {
 	HDC   dc;
 	HGLRC gl;
@@ -351,6 +360,35 @@ gl_error_string(char * buf, int len)
 	return buf;
 }
 
+int 
+gl_context_push(void)
+{
+	CLEAR_ERROR;
+	if ( stack_ptr >= CONTEXT_STACK_SIZE ) {
+		last_error_code  = 1001; /* win32 native error ERROR_STACK_OVERFLOW */
+		last_failed_func = "gl_context_push";
+		return 0;
+	}
+
+	stack[stack_ptr].gl = wglGetCurrentContext();
+	stack[stack_ptr].dc = wglGetCurrentDC();
+	stack_ptr++;
+	return 1;
+}
+
+int 
+gl_context_pop(void)
+{
+	CLEAR_ERROR;
+	if ( stack_ptr <= 0) {
+		last_error_code  = 1001; /* win32 native error ERROR_STACK_OVERFLOW */
+		last_failed_func = "gl_context_pop";
+		return 0;
+	}
+	stack_ptr--;
+	return wglMakeCurrent( stack[stack_ptr].dc, stack[stack_ptr].gl);
+}
+
 #ifdef __cplusplus
 }
 #endif
